@@ -4,7 +4,6 @@ from __future__ import annotations
 from warnings import warn
 
 import numpy as np
-
 from phonopy.harmonic.dynamical_matrix import DynamicalMatrix, DynamicalMatrixNAC
 from phonopy.phonon.degeneracy import degenerate_sets, get_eigenvectors
 from phonopy.structure.atoms import PhonopyAtoms
@@ -17,6 +16,7 @@ from phonopy.structure.cells import (
 )
 from phonopy.structure.symmetry import Symmetry
 from phonopy.units import VaspToTHz
+
 from spgrep_modulation.irreps import (
     get_eigenmode_representation,
     project_eigenmode_representation,
@@ -111,7 +111,7 @@ class Modulation:
             self.primitive,
             self.primitive_symmetry,
             self.qpoint,
-            rtol=self.degeneracy_tolerance,
+            atol=self.degeneracy_tolerance,
         )
 
         # Modified dynamical matrix
@@ -388,7 +388,9 @@ class Modulation:
         qpoint: NDArrayFloat,
         nac_q_direction: NDArrayFloat | None = None,
         factor: float = VaspToTHz,
+        degeneracy_tolerance: float = 1e-4,
         symprec: float = 1e-5,
+        seed: int = 0,
     ) -> Modulation:
         """Return Modulation class with supercell matrix."""
         primitive = dynamical_matrix.primitive
@@ -407,7 +409,9 @@ class Modulation:
             dynamical_matrix=dynamical_matrix,
             qpoint=qpoint,
             nac_q_direction=nac_q_direction,
+            degeneracy_tolerance=degeneracy_tolerance,
             factor=factor,
+            seed=seed,
         )
 
     def eigvals_to_frequencies(self, eigvals: NDArrayComplex) -> NDArrayFloat:
